summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials')
-rw-r--r--qtsharp/src/examples/tutorials/t4.cs4
-rw-r--r--qtsharp/src/examples/tutorials/t5.cs2
-rw-r--r--qtsharp/src/examples/tutorials/t6.cs2
-rw-r--r--qtsharp/src/examples/tutorials/t7.cs2
4 files changed, 5 insertions, 5 deletions
diff --git a/qtsharp/src/examples/tutorials/t5.cs b/qtsharp/src/examples/tutorials/t5.cs
index 0488969d..05ff5e96 100644
--- a/qtsharp/src/examples/tutorials/t5.cs
+++ b/qtsharp/src/examples/tutorials/t5.cs
@@ -13,7 +13,7 @@ public class MyWidget : TQVBox {
TQPushButton quit = new TQPushButton ("Quit", this, "quit");
quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
- TQObject.Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
+ TQObject.Connect ( quit, TQT_SIGNAL ("clicked()"), tqApp, TQT_SLOT ("Quit()") );
TQLCDNumber lcd = new TQLCDNumber (2, this, "lcd" );
diff --git a/qtsharp/src/examples/tutorials/t6.cs b/qtsharp/src/examples/tutorials/t6.cs
index 6fee48e1..910d13d1 100644
--- a/qtsharp/src/examples/tutorials/t6.cs
+++ b/qtsharp/src/examples/tutorials/t6.cs
@@ -31,7 +31,7 @@ public class MyWidget : TQVBox {
TQPushButton quit = new TQPushButton ("Quit", this, "quit");
quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
- Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
+ Connect ( quit, TQT_SIGNAL ("clicked()"), tqApp, TQT_SLOT ("Quit()") );
TQGrid grid = new TQGrid (4, this);
diff --git a/qtsharp/src/examples/tutorials/t7.cs b/qtsharp/src/examples/tutorials/t7.cs
index e1891d26..1372bf15 100644
--- a/qtsharp/src/examples/tutorials/t7.cs
+++ b/qtsharp/src/examples/tutorials/t7.cs
@@ -43,7 +43,7 @@ public class MyWidget : TQVBox {
TQPushButton quit = new TQPushButton ("Quit", this, "quit");
quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
- Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
+ Connect ( quit, TQT_SIGNAL ("clicked()"), tqApp, TQT_SLOT ("Quit()") );
TQGrid grid = new TQGrid (4, this);
diff --git a/qtsharp/src/examples/tutorials/t4.cs b/qtsharp/src/examples/tutorials/t4.cs
index e868cc7e..b3e66a07 100644
--- a/qtsharp/src/examples/tutorials/t4.cs
+++ b/qtsharp/src/examples/tutorials/t4.cs
@@ -17,8 +17,8 @@ public class MyWidget : TQWidget {
quit.SetGeometry (62, 40, 75, 30);
quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold) );
- Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
- // In C++, qApp is a global variable. Here it's a property of the TQObject
+ Connect ( quit, TQT_SIGNAL ("clicked()"), tqApp, TQT_SLOT ("Quit()") );
+ // In C++, tqApp is a global variable. Here it's a property of the TQObject
// class, which we inherit, giving the same effect. We also inherit the
// static method connect().
}